==> lemonade-0.0.6.tgz: package/README.md <==
lemonade
=========

<img src="https://travis-ci.org/runlevel3/lemonade.png?branch=master" alt="Build Status" />

Simple API-oriented framework


## Install

    $ npm install -g lemonade
    
Change to your working dir, and run an install of the application : 

    $ lemonade install
    
Start the application with the options file provided : 

    $ lemonade boot.js

## Getting started

### Kernel links
Edit boot.js and create kernel links to adaptors or daemons via app/loaders or create your own

```js
exports = module.exports = {

    /**
     * Configuration constants
     */
     config : require(__dirname + '/config.js') // Object containing adaptors and daemons 
                                                // configuration options

    /**
     * Boot modules
     */
    ,boot : {

        storage : 'mysqlms' // this will include app/loaders/mysqlms and 
                            // initialize the mysql master slave adaptor
                            
    //, queue   : 'rabbit'
    //, search  : 'solr'

      , ehlo : function() {                      // create your own kernel links
            this.emit('loader-ready', 'ehlo')    // or use a file path
        }
    }

    /**
     * Run modules
     */
    ,run : {
         httpd   : 'httpd'
        ,spinner : 'spinner'
    }

    /**
     * Methods to run on exit
     */
    ,shutdown : {}

};
```

You can then use the links inside the application code : 

```js
//app/models/example.js

function exampleModel() {
    this.kernel.storage().query(
         'SELECT 1'
        ,[]
        ,function() {}
    );
}
```

### Http daemon

### Intervals spinner

### Including files

==> lemonade-0.1.1.tgz: package/README.md <==
lemonade
=========

[![Build Status](https://travis-ci.org/runlevel3/lemonade.png)](https://travis-ci.org/runlevel3/lemonade)
[![Dependency Status](https://gemnasium.com/runlevel3/lemonade.png)](https://gemnasium.com/runlevel3/lemonade)


Simple API-oriented framework


## Install

    $ npm install -g lemonade
    
Change to your working dir, and run an install of the application : 

    $ lemonade install
    
Start the application with the options file provided : 

    $ lemonade config.js

## Getting started

### Kernel links
Edit config.js and create kernel links to adaptors or daemons via app/loaders or create your own

```js
exports = module.exports = {

    /**
     * Configuration constants
     */
     config : require(__dirname + '/config.js') // Object containing adaptors and daemons 
                                                // configuration options

    /**
     * Boot modules
     */
    ,boot : {

        storage : 'mysqlms' // this will include app/loaders/mysqlms and 
                            // initialize the mysql master slave adaptor
                            
    //, queue   : 'rabbit'
    //, search  : 'solr'

      , ehlo : function() {                      // create your own kernel links
            this.emit('loader-ready', 'ehlo')    // or use a file path
        }
    }

    /**
     * Run modules
     */
    ,run : {
         httpd   : 'httpd'
        ,spinner : 'spinner'
    }

    /**
     * Methods to run on exit
     */
    ,shutdown : {}

};
```

You can then use the links inside the application code : 

```js
//app/models/dummy.js

function exampleModel() {
    this.kernel.storage().query(
         'SELECT 1'
        ,[]
        ,function() {}
    );
}
```

### Http daemon

### Intervals spinner

### Including files
